/*
**  CREATABL.SQL
**
**  Create all of the credit database tables.
**
**  Tables are dropped first in case this is a re-creation.
**
**  Don't forget to say 'USE credit' first.
*/


PRINT 'Begin CREATABL.SQL'
GO

USE credit
SET NOCOUNT ON
GO
IF ( (SELECT db_name()) <> 'credit')
BEGIN
   RAISERROR ('Database "credit" not found.',22,1) WITH LOG
END
GO


IF EXISTS (SELECT name FROM sysobjects WHERE type = 'U' AND name = 'category')
    DROP TABLE category
IF EXISTS (SELECT name FROM sysobjects WHERE type = 'U' AND name = 'region')
    DROP TABLE region
IF EXISTS (SELECT name FROM sysobjects WHERE type = 'U' AND name = 'corporation')
    DROP TABLE corporation
IF EXISTS (SELECT name FROM sysobjects WHERE type = 'U' AND name = 'provider')
    DROP TABLE provider
IF EXISTS (SELECT name FROM sysobjects WHERE type = 'U' AND name = 'member')
    DROP TABLE member
IF EXISTS (SELECT name FROM sysobjects WHERE type = 'U' AND name = 'statement')
    DROP TABLE statement
IF EXISTS (SELECT name FROM sysobjects WHERE type = 'U' AND name = 'charge')
    DROP TABLE charge
IF EXISTS (SELECT name FROM sysobjects WHERE type = 'U' AND name = 'payment')
    DROP TABLE payment
IF EXISTS (SELECT name FROM sysobjects WHERE type = 'U' AND name = 'status')
    DROP TABLE status
GO




CREATE TABLE region
  (
     region_no        numeric_id   NOT NULL IDENTITY
  ,  region_name      shortstring  NOT NULL
  ,  street           shortstring  NOT NULL
  ,  city             shortstring  NOT NULL
  ,  state_prov       statecode    NOT NULL
  ,  country          countrycode  NOT NULL
  ,  mail_code        mailcode     NOT NULL
  ,  phone_no         phonenumber  NOT NULL
  ,  region_code      status_code  NOT NULL
  )
  
GO


CREATE TABLE corporation
  (
     corp_no          numeric_id   NOT NULL IDENTITY
  ,  corp_name        normstring   NOT NULL
  ,  street           shortstring  NOT NULL
  ,  city             shortstring  NOT NULL
  ,  state_prov       statecode    NOT NULL
  ,  country          countrycode  NOT NULL
  ,  mail_code        mailcode     NOT NULL
  ,  phone_no         phonenumber  NOT NULL
  ,  expr_dt          datetime     NOT NULL
  ,  region_no        numeric_id   NOT NULL
  ,  corp_code        status_code  NOT NULL
  )
  
GO


CREATE TABLE provider
  (
     provider_no      numeric_id   NOT NULL IDENTITY
  ,  provider_name    shortstring  NOT NULL
  ,  street           shortstring  NOT NULL
  ,  city             shortstring  NOT NULL
  ,  state_prov       statecode    NOT NULL
  ,  mail_code        mailcode     NOT NULL
  ,  country          countrycode  NOT NULL
  ,  phone_no         phonenumber  NOT NULL
  ,  issue_dt         datetime     NOT NULL
  ,  expr_dt          datetime     NOT NULL
  ,  region_no        numeric_id   NOT NULL
  ,  provider_code    status_code  NOT NULL
  )
  
GO


CREATE TABLE member
  (
     member_no        numeric_id   NOT NULL IDENTITY
  ,  lastname         shortstring  NOT NULL 
  ,  firstname        shortstring  NOT NULL 
  ,  middleinitial    letter           NULL
  ,  street           shortstring  NOT NULL
  ,  city             shortstring  NOT NULL
  ,  state_prov       statecode    NOT NULL
  ,  country          countrycode  NOT NULL
  ,  mail_code        mailcode     NOT NULL
  ,  phone_no         phonenumber      NULL
  ,  issue_dt         datetime     NOT NULL
  ,  expr_dt          datetime     NOT NULL
  ,  region_no        numeric_id   NOT NULL
  ,  corp_no          numeric_id       NULL
  ,  prev_balance     money            NULL
  ,  curr_balance     money            NULL
  ,  member_code      status_code  NOT NULL
  )
  
GO


CREATE TABLE statement
  (
     statement_no     numeric_id   NOT NULL IDENTITY
  ,  member_no        numeric_id   NOT NULL
  ,  statement_dt     datetime     NOT NULL
  ,  due_dt           datetime     NOT NULL
  ,  statement_amt    money        NOT NULL
  ,  statement_current   money        NOT NULL
  ,  statement_pastdue   money        NOT NULL
  ,  statement_latechg   money        NOT NULL
  ,  statement_code   status_code  NOT NULL
  )
  
GO


CREATE TABLE charge
  (
     charge_no        numeric_id   NOT NULL IDENTITY
  ,  member_no        numeric_id   NOT NULL
  ,  provider_no      numeric_id   NOT NULL
  ,  category_no      numeric_id   NOT NULL
  ,  charge_dt        datetime     NOT NULL
  ,  charge_amt       money        NOT NULL
  ,  statement_no     numeric_id   NOT NULL
  ,  charge_code      status_code  NOT NULL
  )
  
GO


CREATE TABLE payment
  (
     payment_no       numeric_id   NOT NULL IDENTITY
  ,  member_no        numeric_id   NOT NULL
  ,  payment_due_dt   datetime     NOT NULL
  ,  payment_dt       datetime     NOT NULL
  ,  payment_amt      money        NOT NULL
  ,  payment_principle   money        NOT NULL
  ,  payment_latechg     money        NOT NULL
  ,  statement_no     numeric_id       NULL
  ,  payment_code     status_code  NOT NULL
  )
  
GO


CREATE TABLE category
  (
     category_no      numeric_id   NOT NULL IDENTITY
  ,  category_desc    normstring   NOT NULL
  ,  category_code    status_code  NOT NULL
  )
  
GO


CREATE TABLE status
  (
     status_code      status_code  NOT NULL
  ,  status_desc      normstring   NOT NULL
  )
  
GO


INSERT STATUS VALUES ('  ', 'ACTIVE')
GO



-- Display results.

SELECT 'TABLES' = name
FROM sysobjects
WHERE type = 'U'
SELECT ' ' = ' '
GO


BACKUP LOG credit WITH TRUNCATE_ONLY
GO
